from environs import Env

env = Env()


API_URL = env("ADUMO_API_URL", default="https://staging-apiv2.adumoonline.com/")
CLIENT_ID = env("ADUMO_CLIENT_ID", default="9ba5008c-08ee-4286-a349-54af91a621b0")
CLIENT_SECRET = env(
    "ADUMO_CLIENT_SECRET", default="23adadc0-da2d-4dac-a128-4845a5d71293"
)
APPLICATION_ID = env(
    "ADUMO_APPLICATION_ID", default="23ADADC0-DA2D-4DAC-A128-4845A5D71293"
)
MERCHANT_UID = env("ADUMO_MERCHANT_UID", default="9BA5008C-08EE-4286-A349-54AF91A621B0")



# API_URL = "https://apiv2.adumoonline.com/"
# CLIENT_ID = "01375D13-0146-48DD-A082-1A60C757A418"
# CLIENT_SECRET = "39uR8Z68iPJgNcS-CTB9lel6OzGi-k3KLY0i"
# APPLICATION_ID = "F0D5C26D-4430-4103-92AE-FD10A2695202"
# MERCHANT_UID = "01375D13-0146-48DD-A082-1A60C757A418"



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['adumo']

package_data = \
{'': ['*']}

install_requires = \
['environs>=9.4.0,<10.0.0', 'flake8>=4.0.1,<5.0.0', 'httpx>=0.21.3,<0.22.0']

setup_kwargs = {
    'name': 'adumo',
    'version': '0.1.2',
    'description': '',
    'long_description': None,
    'author': 'Wayne',
    'author_email': 'wayne@flickswitch.co.za',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
